define puppet_enterprise::amq::config::network_connector(
  $brokername,
  $connector_name,
  $additional_attributes              = {},
  $conduit_subscriptions              = true,
  $decrease_network_consumer_priority = true,
  $duplex                             = true,
  $dynamic_only                       = true,
  $excluded_collectives               = [],
  $exported_by                        = undef,
  $included_collectives               = [],
  $network_ttl                        = $puppet_enterprise::params::activemq_network_ttl,
  $openwire_protocol                  = $puppet_enterprise::params::openwire_protocol,
  $stomp_password                     = $puppet_enterprise::params::stomp_password,
  $stomp_user                         = $puppet_enterprise::params::stomp_user,
) {
  pe_validate_array($excluded_collectives, $included_collectives)
  pe_validate_hash($additional_attributes)

  $broker_context            = "/files/etc/puppetlabs/activemq/activemq.xml/beans/broker[#attribute/brokerName='${::clientcert}']"
  $network_connector_context = "${broker_context}/networkConnectors/networkConnector[#attribute/name='${connector_name}']"

  $_connector_name              = "set #attribute/name '${connector_name}'"
  $_uri                         = "set #attribute/uri 'static:(${openwire_protocol}://${brokername}:61616)'"
  $_username                    = "set #attribute/userName ${stomp_user}"
  $_password                    = "set #attribute/password ${stomp_password}"
  $_duplex                      = "set #attribute/duplex ${duplex}"
  $_descrease_consumer_priority = "set #attribute/decreaseNetworkConsumerPriority ${decrease_network_consumer_priority}"
  $_network_ttl                 = "set #attribute/networkTTL ${network_ttl}"
  $_dynamic_only                = "set #attribute/dynamicOnly ${dynamic_only}"
  $_conduit_subscriptions       = "set #attribute/conduitSubscriptions ${conduit_subscriptions}"

  if ! pe_empty($excluded_collectives) {
    $_excluded_collective_topics = pe_suffix(pe_prefix($excluded_collectives, 'set excludedDestinations/topic/#attribute/physicalName '), '.>')
    $_excluded_collective_queues = pe_suffix(pe_prefix($excluded_collectives, 'set excludedDestinations/queue/#attribute/physicalName '), '.>')
  }

  if ! pe_empty($included_collectives) {
    $_included_collective_topics = pe_suffix(pe_prefix($included_collectives, 'set dynamicallyIncludedDestinations/topic/#attribute/physicalName '), '.>')
    $_included_collective_queues = pe_suffix(pe_prefix($included_collectives, 'set dynamicallyIncludedDestinations/queue/#attribute/physicalName '), '.>')
  }

  if ! pe_empty($additional_attributes) {
    $_additional_attributes = pe_prefix(pe_join_keys_to_values($additional_attributes, ' '), 'set #attribute/')
  }

  $changes = pe_delete_undef_values(pe_flatten([
    $_connector_name,
    $_uri,
    $_username,
    $_password,
    $_duplex,
    $_descrease_consumer_priority,
    $_network_ttl,
    $_dynamic_only,
    $_conduit_subscriptions,
    $_additional_attributes,
    $_excluded_collective_topics,
    $_excluded_collective_queues,
    $_included_collective_topics,
    $_included_collective_queues,
  ]
  ))

  augeas { "${brokername}: AMQ network connector: ${connector_name}":
    incl    => '/etc/puppetlabs/activemq/activemq.xml',
    lens    => 'ActiveMQ_XML.lns',
    context => $network_connector_context,
    changes => $changes,
    notify  => Service['pe-activemq'],
  }
}
