class puppet_enterprise::master::puppetserver(
  $certname                                 = $::clientcert,
  $localcacert                              = $puppet_enterprise::params::localcacert,
  $static_files                             = {},
  $java_args                                = $puppet_enterprise::params::puppetserver_java_args,
  $metrics_enabled,
  $metrics_server_id,
  $metrics_jmx_enabled,
  $metrics_graphite_enabled,
  $metrics_graphite_host,
  $metrics_graphite_port,
  $metrics_graphite_update_interval_seconds,
  $profiler_enabled,
) inherits puppet_enterprise::params {

  $console_client_certname = $puppet_enterprise::params::console_client_certname
  $container = 'puppetserver'

  File {
    ensure => present,
    owner  => 'pe-puppet',
    group  => 'pe-puppet',
    mode   => '0640',
  }

  Pe_concat {
    owner  => 'pe-puppet',
    group  => 'pe-puppet',
    mode   => '0640',
  }

  Puppet_enterprise::Trapperkeeper::Bootstrap_cfg {
    container => $container,
  }

  $confdir = "/etc/puppetlabs/${container}"

  puppet_enterprise::trapperkeeper::bootstrap_cfg { "${container}:master jetty9-service" :
    namespace => 'puppetlabs.trapperkeeper.services.webserver.jetty9-service',
    service   => 'jetty9-service',
    notify => Service["pe-${container}"],
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'pe-master-service' :
    namespace => 'puppetlabs.enterprise.services.master.master-service',
    notify => Service["pe-${container}"],
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'request-handler-service' :
    namespace => 'puppetlabs.services.request-handler.request-handler-service',
    notify => Service["pe-${container}"],
  }
  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'jruby-puppet-pooled-service' :
    namespace => 'puppetlabs.services.jruby.jruby-puppet-service',
    notify => Service["pe-${container}"],
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'metrics-puppet-profiler-service' :
    namespace => 'puppetlabs.enterprise.services.puppet-profiler.puppet-profiler-service',
    notify => Service["pe-${container}"],
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'metrics-service' :
    namespace => 'puppetlabs.enterprise.services.metrics.metrics-service',
    notify => Service["pe-${container}"],
  }

  puppet_enterprise::trapperkeeper::bootstrap_cfg { 'puppet-server-config-service' :
    namespace => 'puppetlabs.services.config.puppet-server-config-service',
    notify => Service["pe-${container}"],
  }

  $logpath = "/var/log/pe-${container}/${container}.log"
  # Uses
  #   $logpath
  file { "${confdir}/logback.xml" :
    content => template('puppet_enterprise/master/puppetserver/logback.xml.erb'),
    notify => Service["pe-${container}"],
  }

  # Uses
  #   $certname
  #   $localcacert
  file { "${confdir}/conf.d/webserver.conf" :
    content => template('puppet_enterprise/master/puppetserver/webserver.conf.erb'),
    notify => Service["pe-${container}"],
  }

  # Uses
  #   $profiler_enabled
  file { "${confdir}/conf.d/pe-puppet-server.conf" :
    content => template('puppet_enterprise/master/puppetserver/puppet-server.conf.erb'),
    notify => Service["pe-${container}"],
  }

  # Uses
  #   $confdir
  #   $certname
  file { "${confdir}/conf.d/global.conf" :
    content => template('puppet_enterprise/master/puppetserver/global.conf.erb'),
    notify => Service["pe-${container}"],
  }

  # Uses
  #   $console_client_certname
  file { "${confdir}/conf.d/ca.conf" :
    content => template('puppet_enterprise/master/puppetserver/ca.conf.erb'),
    notify => Service["pe-${container}"],
  }

  # Uses
  #   $metrics_enabled
  #   $metrics_server_id
  #   $metrics_jmx_enabled
  #   $metrics_graphite_enabled
  #   $metrics_graphite_host
  #   $metrics_graphite_port
  #   $metrics_graphite_update_interval_seconds
  file { "${confdir}/conf.d/metrics.conf" :
    content => template('puppet_enterprise/master/puppetserver/metrics.conf.erb'),
    notify => Service["pe-${container}"],
  }

  if !pe_empty($java_args) {
    $puppetserver_initconf = "${puppet_enterprise::params::defaults_dir}/pe-puppetserver"
    create_resources(
      'pe_ini_subsetting',
      create_java_args_subsettings_hash(
        'pe-puppetserver',
        $java_args,
        { path => $puppetserver_initconf,
          require => Package['pe-puppetserver'],
          notify => Service["pe-${container}"],
        })
    )
  }

  service { "pe-${container}":
    ensure    => running,
    enable    => true,
  }
}
