# == Class: puppet_enterprise::profile::mcollective::peadmin
#
# Profile for creating the peadmin mcollective user && client. This is a special user that lives on
# the puppet master node and is intended for issuing orchestration commands.
#
# === Parameters
#
# [*create_user*]
#   Whether or not we should create and manage this users account on disk.
#
# [*home_dir*]
#   The home directory of the peadmin system user. Defaults to `/var/lib/peadmin`.
#
# [*stomp_passowrd*]
#   The stomp password. But default this is read from disk.
#
# [*stomp_port*]
#   The port that the stomp service is listening on
#
# [*stomp_user*]
#   The username for sending messages over the stomp protocol.
#
class puppet_enterprise::profile::mcollective::peadmin(
  $activemq_brokers       = $puppet_enterprise::mcollective_middleware_hosts,
  $create_user            = $puppet_enterprise::params::mco_create_client_user,
  $home_dir               = '/var/lib/peadmin',
  $stomp_password         = $puppet_enterprise::mcollective_middleware_password,
  $stomp_port             = $puppet_enterprise::mcollective_middleware_port,
  $stomp_user             = $puppet_enterprise::mcollective_middleware_user,
) inherits puppet_enterprise {

  puppet_enterprise::mcollective::client { 'peadmin':
    activemq_brokers => $activemq_brokers,
    cert_name        => $puppet_enterprise::params::mco_peadmin_client_name,
    keypair_name     => $puppet_enterprise::params::mco_peadmin_keypair_name,
    create_user      => $create_user,
    home_dir         => $home_dir,
    logfile          => "${home_dir}/.mcollective.d/client.log",
    stomp_password   => $stomp_password,
    stomp_port       => $stomp_port,
    stomp_user       => $stomp_user,
  }
}
