require 'spec_helper'

describe 'puppet_enterprise::console' do
  before :all do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'console.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
    }

    @params = { 'secret_token' => 'totally secret',
                'database_password' => 'password',
                'database_host' => 'database.rspec',
                'console_server_certname' => 'console.server.rspec',
                'console_client_certname' => 'console.client.rspec',
                'master_host' => 'master.rspec',
                'ca_host' => 'ca.rspec',
                'puppetdb_host' => 'puppetdb.rspec' }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:sharedir) { '/opt/puppet/share/puppet-dashboard' }
  let(:ssldir) { '/etc/puppetlabs/puppet/ssl' }

  context "when managing config" do
    it { should contain_class('puppet_enterprise::console::config').with_console_server_certname('console.server.rspec') }
  end

  context "managing the database" do
    it { should contain_class('puppet_enterprise::console::database').with_database_host('database.rspec') }
  end

  context "managing services" do
    it { should contain_service('pe-httpd').with_ensure('running') }
    it { should contain_service('pe-puppet-dashboard-workers').with_ensure('running') }
  end
end
