require 'spec_helper'

describe 'puppet_enterprise::master' do
  before :each do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'master.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
      'processorcount'    => '1',
    }

    @params = { 'certname' => 'master.rspec',
                'metrics_enabled' => true,
                'metrics_server_id' => 'localhost',
                'metrics_jmx_enabled' => true,
                'metrics_graphite_enabled' => false,
                'metrics_graphite_host' => 'graphite',
                'metrics_graphite_port' => 2003,
                'metrics_graphite_update_interval_seconds' => 30,
                'profiler_enabled' => true }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:confdir) { "/etc/puppetlabs/puppet" }

  context "with invalid dns_alt_names" do
    before :each do
      @params['dns_alt_names'] = 'just a string'
    end

    it "fails to compile" do
      expect { subject }.to raise_error(Puppet::Error, /is not an Array/)
    end
  end

  context "when managing default java_args" do
    context "1 GB of RAM => 512 MB heap" do
      before(:each) { @facter_facts['memorysize'] = '1073741824' }
      it { should contain_pe_ini_subsetting("pe-puppetserver_'Xmx'").with_value( '512m' ) }
      it { should contain_pe_ini_subsetting("pe-puppetserver_'Xms'").with_value( '512m' ) }
    end

    context "2 GB of RAM => 1 GB heap" do
      before(:each) { @facter_facts['memorysize'] = '2147483648' }
      it { should contain_pe_ini_subsetting("pe-puppetserver_'Xmx'").with_value('1024m') }
      it { should contain_pe_ini_subsetting("pe-puppetserver_'Xms'").with_value('1024m') }
    end

    context "4 GB of RAM => 2 GB heap" do
      before(:each) { @facter_facts['memorysize'] = '4294967296' }
      it { should contain_pe_ini_subsetting("pe-puppetserver_'Xmx'").with_value( '2048m' ) }
      it { should contain_pe_ini_subsetting("pe-puppetserver_'Xms'").with_value( '2048m' ) }
    end
  end

  context "wth custom java_args" do
    before(:each) { @params['java_args'] = { 'Xmx' => '128m' } }
    it { should contain_pe_ini_subsetting("pe-puppetserver_'Xmx'").with(
     'value'   => '128m',
     'require' => 'Package[pe-puppetserver]',
    ) }
  end

  context "managing files" do
    it { should contain_file("/var/log/pe-puppet").with_mode('0640') }
    it { should contain_file("/etc/puppetlabs/puppet/environments").with_mode('0644') }

    it { should contain_pe_ini_setting("certname").with_value('master.rspec') }
    it { should contain_pe_ini_setting("always_cache_features").with_value('true') }
    it { should contain_class('puppet_enterprise::master::puppetserver') }
  end


  context "managing puppetsever" do
    it { should contain_package('pe-puppetserver') }
    it { should contain_package('pe-java') }
    it { should contain_class('puppet_enterprise::master::puppetserver') }
  end

end
