require 'spec_helper'

describe 'puppet_enterprise::trapperkeeper::console_services' do
  before :all do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'lsbmajdistrelease' => '6',
      'puppetversion'     => '3.6.2 (Puppet Enterprise 3.3.0)',
      'is_pe'             => 'true',
      'fqdn'              => 'classifier_ui.rspec',
      'clientcert'        => 'awesomecert',
      'pe_concat_basedir'    => '/tmp/file',
    }

    @params = {
      'puppetdb_host' => 'puppetdb.rspec',
      'puppetdb_port' => 54321,
      'dashboard_port' => 443,
      'classifier_host' => 'classifier.rspec',
      'classifier_port' => '4242',
      'classifier_url_prefix' => '/classifier-api',
      'rbac_host' => 'rbac.rspec',
      'rbac_port' => '4244',
      'rbac_url_prefix' => '/rbac-api',
      'activity_host' => 'activity.rspec',
      'activity_port' => '4243',
      'activity_url_prefix' => '/activity-api',
      'client_certname' => 'classifier_ui.rspec',
    }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:title) { 'console-services' }

  context "when the parameters are valid" do
    it { should contain_file("/etc/puppetlabs/console-services/conf.d/console.conf").with(:owner => "pe-console-services",
                                                                                             :group => "pe-console-services",
                                                                                             :mode => "0640") }
    it { should contain_file('/etc/puppetlabs/console-services/conf.d/console.conf').with_content(%r[classifier-server: "http://classifier.rspec:4242/classifier-api"]) }
    it { should contain_file('/etc/puppetlabs/console-services/conf.d/console.conf').with_content(%r[activity-server: "http://activity.rspec:4243/activity-api"]) }
    it { should contain_file('/etc/puppetlabs/console-services/conf.d/console.conf').with_content(%r[rbac-server: "http://rbac.rspec:4244/rbac-api"]) }
    it { should contain_file('/etc/puppetlabs/console-services/conf.d/console.conf').with_content(%r[dashboard-server: "http://127.0.0.1:443"]) }
    it { should contain_file('/etc/puppetlabs/console-services/conf.d/console.conf').with_content(%r[ssl-cert: "/opt/puppet/share/console-services/certs/classifier_ui.rspec.cert.pem"]) }

    it { should contain_file("/etc/puppetlabs/console-services/conf.d/console_secret_key.conf").with(:owner => "pe-console-services",
                                                                                                      :group => "pe-console-services",
                                                                                                      :mode => "0640",
                                                                                                      :replace => false) }
    it { should contain_file('/etc/puppetlabs/console-services/conf.d/console_secret_key.conf').with_content(%r[cookie-secret-key: "(.){16}"]) }

    it { should contain_pe_concat__fragment('console-services classifier-ui-service') }
    it { should contain_pe_concat__fragment('console-services jetty9-service') }
    it { should contain_pe_concat__fragment('console-services rbac-ui-service') }
    it { should contain_pe_concat__fragment('console-services rbac-authn-service') }
    it { should contain_pe_concat__fragment('console-services rbac-authn-middleware') }
    it { should contain_pe_concat__fragment('console-services rbac-service') }
    it { should contain_pe_concat__fragment('console-services rbac-storage-service') }
    it { should contain_pe_concat__fragment('console-services proxy-service') }
    it { should contain_pe_concat__fragment('console-services helpers-service') }
  end

end

